@@ -1,4 +1,4 @@
-# Copyright (c) 1997-8 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 1997-2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -20,7 +20,7 @@ use Net::LDAP::Constant qw(LDAP_SUCCESS
 			   LDAP_LOCAL_ERROR
 			);
 
-$VERSION = "0.14";
+$VERSION = "0.15";
 
 $LDAP_VERSION = 2;      # default LDAP protocol version
 
@@ -110,7 +110,11 @@ sub new {
 }
 
 sub async {
-  $_[0]->{'net_ldap_async'};
+  my $ldap = shift;
+
+  @_
+    ? ($ldap->{'net_ldap_async'},$ldap->{'net_ldap_async'} = shift)[0]
+    : $ldap->{'net_ldap_async'};
 }
 
 sub debug {
