@@ -1,4 +1,4 @@
-# Copyright (c) 1998 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 1997-2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -130,7 +130,7 @@ sub sorted {
     my $attr = shift;
 
     @at = map {
-      my $x = $_->attribute($attr);
+      my $x = $_->get($attr);
       $x ? lc(join("\001",@$x)) : "";
     } @{$self->{'Entries'}};
   }
