@@ -1,3 +1,9 @@
+# Copyright (c) 1999-2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# This program is free software; you can redistribute it and/or
+# modify it under the same terms as Perl itself.
+
+package Net::LDAP::Util;
+
 =head1 NAME
 
 Net::LDAP::Util -- Utility functions
@@ -94,7 +100,7 @@ Graham Barr E<lt>F<gbarr@pobox.com>E<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 1999 Graham Barr. All rights reserved. This program is
+Copyright (c) 1999-2000 Graham Barr. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
